
dialogId("dlg-x-poster1", "font_poster", "Squirrel - this is a notion that will be effective today widely talked about in the next few years in connection with interspace propulsion. This is also possible reason of UFO visits of the Earth.")
dialogStr("Eekhoorntje - een begrip dat de komende paar jaren flink wat stof zal doen opwaaien in verband met ruimtereizen. Dit is waarschijnlijk ook de reden dat vliegende schotels de Aarde bezoeken.")


dialogId("dlg-x-poster2", "font_poster", "Yes, a few cases of squirrel kidnaps were reported in past 5 years, especially from Arizona, Utah and Southern Moravia, but no one really took them seriously. Now we know the whole appalling truth. Technical description is included.")
dialogStr("Ja, in de afgelopen vijf jaar zijn een aantal gevallen van eekhoornontvoeringen gemeld, vooral vanuit Arizona, Utah en Zuid Moravië. Maar niemand nam die meldingen erg serieus. Nu weten we de volledige, vreselijke waarheid. Hier is de technische beschrijving.")

